@@ -255,8 +255,15 @@ rndr_quote(struct buf *ob, const struct buf *text, void *opaque)
 	if (!text || !text->size)
 		return 0;
 
+	struct html_renderopt *options = opaque;
+
 	BUFPUTSL(ob, "<q>");
-	bufput(ob, text->data, text->size);
+
+	if (options->flags & HTML_ESCAPE)
+		escape_html(ob, text->data, text->size);
+	else
+		bufput(ob, text->data, text->size);
+
 	BUFPUTSL(ob, "</q>");
 
 	return 1;
@@ -326,7 +333,8 @@ rndr_header(struct buf *ob, const struct buf *text, int level, void *opaque)
 	if (ob->size)
 		bufputc(ob, '\n');
 
-	if ((options->flags & HTML_TOC) && (level <= options->toc_data.nesting_level)) {
+	if ((options->flags & HTML_TOC) && level >= options->toc_data.nesting_bounds[0] &&
+	     level <= options->toc_data.nesting_bounds[1]) {
 		bufprintf(ob, "<h%d id=\"", level);
 		rndr_header_anchor(ob, text);
 		BUFPUTSL(ob, "\">");
@@ -655,7 +663,7 @@ rndr_footnote_def(struct buf *ob, const struct buf *text, unsigned int num, void
 	bufprintf(ob, "\n<li id=\"fn%d\">\n", num);
 	if (pfound) {
 		bufput(ob, text->data, i);
-		bufprintf(ob, "&nbsp;<a href=\"#fnref%d\" rev=\"footnote\">&#8617;</a>", num);
+		bufprintf(ob, "&nbsp;<a href=\"#fnref%d\">&#8617;</a>", num);
 		bufput(ob, text->data + i, text->size - i);
 	} else if (text) {
 		bufput(ob, text->data, text->size);
@@ -666,7 +674,7 @@ rndr_footnote_def(struct buf *ob, const struct buf *text, unsigned int num, void
 static int
 rndr_footnote_ref(struct buf *ob, unsigned int num, void *opaque)
 {
-	bufprintf(ob, "<sup id=\"fnref%d\"><a href=\"#fn%d\" rel=\"footnote\">%d</a></sup>", num, num, num);
+	bufprintf(ob, "<sup id=\"fnref%d\"><a href=\"#fn%d\">%d</a></sup>", num, num, num);
 	return 1;
 }
 
@@ -675,7 +683,8 @@ toc_header(struct buf *ob, const struct buf *text, int level, void *opaque)
 {
 	struct html_renderopt *options = opaque;
 
-	if (level <= options->toc_data.nesting_level) {
+	if (level >= options->toc_data.nesting_bounds[0] &&
+	    level <= options->toc_data.nesting_bounds[1]) {
 		/* set the level offset if this is the first header
 		 * we're parsing for the document */
 		if (options->toc_data.current_level == 0)
@@ -824,7 +833,8 @@ sdhtml_renderer(struct sd_callbacks *callbacks, struct html_renderopt *options,
 	/* Prepare the options pointer */
 	memset(options, 0x0, sizeof(struct html_renderopt));
 	options->flags = render_flags;
-	options->toc_data.nesting_level = 99;
+	options->toc_data.nesting_bounds[0] = 1;
+	options->toc_data.nesting_bounds[1] = 6;
 
 	/* Prepare the callbacks */
 	memcpy(callbacks, &cb_default, sizeof(struct sd_callbacks));
